@@ -2,7 +2,7 @@ from logging import Logger
 import os
 from abc import ABC, abstractmethod
 
-from .kxy_logger import KxyLogger
+from .kxy_logger import KxyLogger, VirtualLogger
 
 class BaseConfig(ABC):
     BussinessLog = False
@@ -19,7 +19,7 @@ class BaseConfig(ABC):
     @abstractmethod
     def JWT_ALGORITHM(self):
         pass
-    AppLogger:KxyLogger = None
+    AppLogger:KxyLogger = VirtualLogger()
 
     def env_first(self):
         for name in [f for f in dir(self) if not callable(f) and not f.startswith('__')]:
