@@ -11,7 +11,9 @@ if project_root not in sys.path:
     
 from kxy.framework.slogger import create_logger
 
-logger,handler = create_logger(logging.DEBUG,'kxy.mall.api','production',filename='log/app',file_type='log',backupCount=5,maxBytes=1000,mutiple_process=False,cleanup_mode='zip',disk_max=1)
+create_logger(logging.DEBUG,'kxy.mall.api','production',filename='log/app',file_type='log',backupCount=5,maxBytes=10000,mutiple_process=False,cleanup_mode='zip',disk_max=1)
+
+logger = logging.getLogger(__name__)
 
 
 logger.info('hello world1',extra={"logCategory":'http'})
